@@ -4,6 +4,7 @@ import requests
 from requests.sessions import Session
 
 from simple_proxy.proxy_pool import ProxyPool, PROTOCOL, build_proxy_pool
+from simple_proxy.user_agents import get_random_useragent
 
 
 class ProxiedSession(Session):
@@ -21,7 +22,7 @@ class ProxiedSession(Session):
         retry_limit = 1000
         retries = 0
 
-        f_header = {'User-Agent': self.__proxy_pool.get_random_useragent()}
+        f_header = {'User-Agent': get_random_useragent()}
         if headers is not None:
             f_header.update(headers)
 
