@@ -61,9 +61,10 @@ class ProxyManager:
                 return self._success / self._trials
 
     def proxy_session(self,
-                      fn: Callable[[Session], Optional[Any]],
+                      fn: Callable[[Session, tuple], Optional[Any]],
                       callback_async: Callable[[Optional[Any]], None] = lambda x: None,
-                      exception_handle: Callable[[ProxyInfo, Exception], None] = lambda info, ex: print(info, ex)):
+                      exception_handle: Callable[[ProxyInfo, Exception], None] = lambda info, ex: print(info, ex),
+                      args: tuple = ()):
         def task():
             success = False
 
@@ -77,7 +78,7 @@ class ProxyManager:
                     timer = SimpleTimer()
                     try:
                         with timer:
-                            result = fn(session)
+                            result = fn(session, *args)
 
                         if type(result) is tuple:
                             callback_async(*result)
